@@ -7,9 +7,10 @@
 @Email   :   bj.yan.pa@qq.com
 """
 
-__all__ = ["opts", "Logger", "Serializer", "Deserializer", "Message", "Unpickler"]
+__all__ = ["opts", "Logger", "Serializer", "Deserializer", "Message"]
 
 from .opt import opts
 from .logger import Logger
-from .message import Message
-from .serial import Serializer, Deserializer, Unpickler
\ No newline at end of file
+from .serial import Serializer, Deserializer
+
+from .type import *
\ No newline at end of file
